==> react-molecule-checkbox-field-2.0.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomCheckbox from '@s-ui/react-atom-checkbox';
var BASE_CLASS = 'sui-MoleculeCheckboxField';

var MoleculeCheckboxField = function MoleculeCheckboxField(_ref) {
  var id = _ref.id,
      label = _ref.label,
      successText = _ref.successText,
      errorText = _ref.errorText,
      helpText = _ref.helpText,
      onChange = _ref.onChange,
      ToggleIcon = _ref.toggleIcon,
      _ref$toggleIconOnChan = _ref.toggleIconOnChange,
      toggleIconOnChange = _ref$toggleIconOnChan === void 0 ? function () {} : _ref$toggleIconOnChan,
      props = _objectWithoutPropertiesLoose(_ref, ["id", "label", "successText", "errorText", "helpText", "onChange", "toggleIcon", "toggleIconOnChange"]);

  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement(MoleculeField, {
    name: id,
    label: label,
    successText: successText,
    errorText: errorText,
    helpText: helpText,
    onChange: onChange,
    inline: true,
    reverse: true
  }, React.createElement(AtomCheckbox, Object.assign({
    id: id
  }, props)), ToggleIcon && React.createElement("span", {
    className: BASE_CLASS + "-toggleIcon",
    onClick: toggleIconOnChange
  }, React.createElement(ToggleIcon, null))));
};

MoleculeCheckboxField.displayName = 'MoleculeCheckboxField';
export default MoleculeCheckboxField;

==> react-molecule-checkbox-field-2.2.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomCheckbox from '@s-ui/react-atom-checkbox';
var BASE_CLASS = 'sui-MoleculeCheckboxField';

var MoleculeCheckboxField = function MoleculeCheckboxField(_ref) {
  var id = _ref.id,
      label = _ref.label,
      successText = _ref.successText,
      errorText = _ref.errorText,
      alertText = _ref.alertText,
      helpText = _ref.helpText,
      onChange = _ref.onChange,
      ToggleIcon = _ref.toggleIcon,
      _ref$toggleIconOnChan = _ref.toggleIconOnChange,
      toggleIconOnChange = _ref$toggleIconOnChan === void 0 ? function () {} : _ref$toggleIconOnChan,
      props = _objectWithoutPropertiesLoose(_ref, ["id", "label", "successText", "errorText", "alertText", "helpText", "onChange", "toggleIcon", "toggleIconOnChange"]);

  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement(MoleculeField, {
    name: id,
    label: label,
    successText: successText,
    errorText: errorText,
    alertText: alertText,
    helpText: helpText,
    onChange: onChange,
    inline: true,
    reverse: true
  }, React.createElement(AtomCheckbox, Object.assign({
    id: id
  }, props)), ToggleIcon && React.createElement("span", {
    className: BASE_CLASS + "-toggleIcon",
    onClick: toggleIconOnChange
  }, React.createElement(ToggleIcon, null))));
};

MoleculeCheckboxField.displayName = 'MoleculeCheckboxField';
export default MoleculeCheckboxField;
